@@ -245,7 +245,7 @@ void ffListFeatures(void)
         #if FF_HAVE_DDCUTIL
             "libddcutil\n"
         #endif
-        #if FF_HAVE_ELF || __sun || __FreeBSD__ || __OpenBSD__
+        #if FF_HAVE_ELF || __sun || (__FreeBSD__ && !__DragonFly__) || __OpenBSD__ || __NetBSD__
             "libelf\n"
         #endif
         #if FF_HAVE_LIBZFS
